# -*- coding: utf-8 -*-
"""rafm -- reliability of AlphaFold measures.

\b
For complete help visit https://github.com/unmtransinfo/rafm
\b
License: MIT
Copyright © 2021, The University of New Mexico.
All rights reserved.
"""  # noqa: D301

from importlib import metadata

NAME = "rafm"
VERSION: str = metadata.version(NAME)